@@ -75,12 +75,14 @@ typedef struct
   gboolean device_is_linux_lvm2_pv;
   gboolean device_is_linux_dmmp;
   gboolean device_is_linux_dmmp_component;
+  gboolean device_is_linux_loop;
   char **device_mount_paths;
   uid_t device_mounted_by_uid;
   gboolean device_presentation_hide;
   gboolean device_presentation_nopolicy;
   char *device_presentation_name;
   char *device_presentation_icon_name;
+  char *device_automount_hint;
   guint64 device_size;
   guint64 device_block_size;
 
@@ -192,6 +194,8 @@ typedef struct
   gchar **linux_dmmp_slaves;
   gchar *linux_dmmp_parameters;
 
+  gchar *linux_loop_filename;
+
 } DeviceProperties;
 
 static void
@@ -260,6 +264,8 @@ collect_props (const char *key,
     props->device_is_linux_dmmp = g_value_get_boolean (value);
   else if (strcmp (key, "DeviceIsLinuxDmmpComponent") == 0)
     props->device_is_linux_dmmp_component = g_value_get_boolean (value);
+  else if (strcmp (key, "DeviceIsLinuxLoop") == 0)
+    props->device_is_linux_loop = g_value_get_boolean (value);
   else if (strcmp (key, "DeviceIsMounted") == 0)
     props->device_is_mounted = g_value_get_boolean (value);
   else if (strcmp (key, "DeviceMountPaths") == 0)
@@ -274,6 +280,8 @@ collect_props (const char *key,
     props->device_presentation_name = g_strdup (g_value_get_string (value));
   else if (strcmp (key, "DevicePresentationIconName") == 0)
     props->device_presentation_icon_name = g_strdup (g_value_get_string (value));
+  else if (strcmp (key, "DeviceAutomountHint") == 0)
+    props->device_automount_hint = g_strdup (g_value_get_string (value));
   else if (strcmp (key, "DeviceSize") == 0)
     props->device_size = g_value_get_uint64 (value);
   else if (strcmp (key, "DeviceBlockSize") == 0)
@@ -523,6 +531,9 @@ collect_props (const char *key,
   else if (strcmp (key, "LinuxDmmpParameters") == 0)
     props->linux_dmmp_parameters = g_strdup (g_value_get_string (value));
 
+  else if (strcmp (key, "LinuxLoopFilename") == 0)
+    props->linux_loop_filename = g_strdup (g_value_get_string (value));
+
   else
     handled = FALSE;
 
@@ -541,6 +552,7 @@ device_properties_free (DeviceProperties *props)
   g_strfreev (props->device_mount_paths);
   g_free (props->device_presentation_name);
   g_free (props->device_presentation_icon_name);
+  g_free (props->device_automount_hint);
   g_free (props->job_id);
   g_free (props->id_usage);
   g_free (props->id_type);
@@ -605,6 +617,8 @@ device_properties_free (DeviceProperties *props)
   g_strfreev (props->linux_dmmp_slaves);
   g_free (props->linux_dmmp_parameters);
 
+  g_free (props->linux_loop_filename);
+
   g_free (props);
 }
 
@@ -1041,6 +1055,12 @@ gdu_device_is_linux_dmmp_component (GduDevice *device)
         return device->priv->props->device_is_linux_dmmp_component;
 }
 
+gboolean
+gdu_device_is_linux_loop (GduDevice *device)
+{
+        return device->priv->props->device_is_linux_loop;
+}
+
 gboolean
 gdu_device_is_mounted (GduDevice *device)
 {
@@ -1277,6 +1297,12 @@ gdu_device_drive_get_media_compatibility (GduDevice *device)
         return device->priv->props->drive_media_compatibility;
 }
 
+const char *
+gdu_device_get_automount_hint (GduDevice *device)
+{
+        return device->priv->props->device_automount_hint;
+}
+
 const char *
 gdu_device_drive_get_media (GduDevice *device)
 {
@@ -1617,6 +1643,12 @@ gdu_device_linux_dmmp_get_parameters (GduDevice *device)
         return device->priv->props->linux_dmmp_parameters;
 }
 
+const char *
+gdu_device_linux_loop_get_filename (GduDevice *device)
+{
+        return device->priv->props->linux_loop_filename;
+}
+
 /* ---------------------------------------------------------------------------------------------------- */
 
 gboolean
